from __future__ import unicode_literals

import ast
import os

import nose
from nose.plugins import Plugin


class SetEnvironmentVariables(Plugin):
    """
    This plugin is used to set environment variables to seamlessly integrate
    in the nosetests architecture.

    """

    # required attributes by nose
    enabled = True
    name = 'env-setter'

    def options(self, parser, env):
        super(SetEnvironmentVariables, self).options(parser, env=env)
        parser.add_option(
            '--set-env-variables',
            dest='set_env_variables',
            default=None,
            help='The environment variables to set/override',
        )

    def configure(self, options, conf):
        super(SetEnvironmentVariables, self).configure(options, conf)

        if not options.set_env_variables:
            return

        env_variables_to_override = ast.literal_eval(options.set_env_variables)
        for env_key, env_val in env_variables_to_override.iteritems():
            os.environ[env_key] = env_val


if __name__ == '__main__':
    nose.main(addplugins=[SetEnvironmentVariables()])



import os

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


PATH_TO_FILE = os.path.dirname(__file__)


with open(os.path.join(PATH_TO_FILE, 'README.rst')) as f:
    long_description = f.read()


VERSION = (0, 1)


# Dynamically calculate the version based on VERSION tuple
if len(VERSION) > 2 and VERSION[2] is not None:
    str_version = "%s.%s_%s" % VERSION[:3]
else:
    str_version = "%s.%s" % VERSION[:2]


version = str_version


setup(
    name='nose-setenv',
    version=version,
    description="A python nose plugin to override environment variables.",
    long_description=long_description,
    author='Mahmoud Abdelkader',
    author_email='mabdelkader@gmail.com',
    url='https://github.com/mahmoudimus/nose-setenv',
    install_requires=[
        'nose >=1.0.0',
    ],
    setup_requires=[],
    test_suite='nose.collector',
    zip_safe=False,
    packages=['nose_setenv'],
    classifiers=[
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
